# Guide

```{toctree}
:hidden:
:caption: Overview

introduction
tutorial
tutorial2
```

```{toctree}
:hidden:
:caption: "How to"

setup
query-search
track
annotate
can-validate
annotate-for-developers
bio-registries
schemas
transfer
```

```{toctree}
:hidden:
:caption: Other topics

faq
storage
```
